'use strict';

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _from = require('babel-runtime/core-js/array/from');

var _from2 = _interopRequireDefault(_from);

var _matchesSelector = require('matches-selector');

var _matchesSelector2 = _interopRequireDefault(_matchesSelector);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Find all elements within the mounted element(s) matching a given selector.
 *
 * @param {string} selector The selector to use.
 * @returns {MountedComponent} A new MountedComponent.
 */
exports.find = function componentFind(selector) {
  var found = [];

  (0, _from2.default)(this._el).forEach(function (el) {
    found.push.apply(found, (0, _toConsumableArray3.default)(el.querySelectorAll(selector)));
  });

  if (!found.length) {
    return null;
  }

  return this._newFromThis(found);
};

/**
 * Find all children of mounted element(s), optionally matching a given
 * selector.
 *
 * @param {string} [selector] The selector to filter by.
 * @returns {MountedComponent} A new MountedComponent.
 */
exports.children = function componentChildren(selector) {
  var children = [];

  (0, _from2.default)(this._el).forEach(function (el) {
    var _children;

    return (_children = children).push.apply(_children, (0, _toConsumableArray3.default)(el.children));
  });

  if (selector) {
    children = children.filter(function (child) {
      return (0, _matchesSelector2.default)(child, selector);
    });
  }

  if (!children.length) {
    return null;
  }

  return this._newFromThis(children);
};

/**
 * Returns the parent of a mounted element. Will search upwards until it finds
 * a parent matching the given selector.
 *
 * @returns {MountedComponent} A new MountedComponent.
 */
exports.parent = function componentParent(selector) {
  var parent = this._el[0].parentElement;

  if (!selector) {
    return this._newFromThis(parent);
  }

  while (parent && !(0, _matchesSelector2.default)(parent, selector)) {
    parent = parent.parentElement;
  }

  if (!parent) {
    return null;
  }

  return this._newFromThis(parent);
};